summaryrefslogtreecommitdiff
path: root/drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c
diff options
context:
space:
mode:
authorStanislaw Gruszka <sgruszka@redhat.com>2011-08-26 15:43:47 +0200
committerStanislaw Gruszka <sgruszka@redhat.com>2011-11-15 12:26:28 +0100
commitebf0d90d12cf013019005a8ee7d1bc8599935356 (patch)
treef27891764f31133a39f2a6f3280987e3612a75e7 /drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c
parentb73bb5f13bb60735a846b73125e297ab6e3eece5 (diff)
downloadlwn-ebf0d90d12cf013019005a8ee7d1bc8599935356.tar.gz
lwn-ebf0d90d12cf013019005a8ee7d1bc8599935356.zip
iwlegacy: s/statistics/stats/
Signed-off-by: Stanislaw Gruszka <sgruszka@redhat.com>
Diffstat (limited to 'drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c')
-rw-r--r--drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c90
1 files changed, 45 insertions, 45 deletions
diff --git a/drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c b/drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c
index 40e3a7065f23..88b3d8fc38f8 100644
--- a/drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c
+++ b/drivers/net/wireless/iwlegacy/iwl-3945-debugfs.c
@@ -29,22 +29,22 @@
#include "iwl-3945-debugfs.h"
-static int il3945_statistics_flag(struct il_priv *il, char *buf, int bufsz)
+static int il3945_stats_flag(struct il_priv *il, char *buf, int bufsz)
{
int p = 0;
p += scnprintf(buf + p, bufsz - p, "Statistics Flag(0x%X):\n",
- le32_to_cpu(il->_3945.statistics.flag));
- if (le32_to_cpu(il->_3945.statistics.flag) &
+ le32_to_cpu(il->_3945.stats.flag));
+ if (le32_to_cpu(il->_3945.stats.flag) &
UCODE_STATISTICS_CLEAR_MSK)
p += scnprintf(buf + p, bufsz - p,
"\tStatistics have been cleared\n");
p += scnprintf(buf + p, bufsz - p, "\tOperational Frequency: %s\n",
- (le32_to_cpu(il->_3945.statistics.flag) &
+ (le32_to_cpu(il->_3945.stats.flag) &
UCODE_STATISTICS_FREQUENCY_MSK)
? "2.4 GHz" : "5.2 GHz");
p += scnprintf(buf + p, bufsz - p, "\tTGj Narrow Band: %s\n",
- (le32_to_cpu(il->_3945.statistics.flag) &
+ (le32_to_cpu(il->_3945.stats.flag) &
UCODE_STATISTICS_NARROW_BAND_MSK)
? "enabled" : "disabled");
return p;
@@ -57,14 +57,14 @@ ssize_t il3945_ucode_rx_stats_read(struct file *file,
struct il_priv *il = file->private_data;
int pos = 0;
char *buf;
- int bufsz = sizeof(struct iwl39_statistics_rx_phy) * 40 +
- sizeof(struct iwl39_statistics_rx_non_phy) * 40 + 400;
+ int bufsz = sizeof(struct iwl39_stats_rx_phy) * 40 +
+ sizeof(struct iwl39_stats_rx_non_phy) * 40 + 400;
ssize_t ret;
- struct iwl39_statistics_rx_phy *ofdm, *accum_ofdm, *delta_ofdm,
+ struct iwl39_stats_rx_phy *ofdm, *accum_ofdm, *delta_ofdm,
*max_ofdm;
- struct iwl39_statistics_rx_phy *cck, *accum_cck, *delta_cck, *max_cck;
- struct iwl39_statistics_rx_non_phy *general, *accum_general;
- struct iwl39_statistics_rx_non_phy *delta_general, *max_general;
+ struct iwl39_stats_rx_phy *cck, *accum_cck, *delta_cck, *max_cck;
+ struct iwl39_stats_rx_non_phy *general, *accum_general;
+ struct iwl39_stats_rx_non_phy *delta_general, *max_general;
if (!il_is_alive(il))
return -EAGAIN;
@@ -77,23 +77,23 @@ ssize_t il3945_ucode_rx_stats_read(struct file *file,
/*
* The statistic information display here is based on
* the last statistics notification from uCode
* might not reflect the current uCode activity
*/
- ofdm = &il->_3945.statistics.rx.ofdm;
- cck = &il->_3945.statistics.rx.cck;
- general = &il->_3945.statistics.rx.general;
- accum_ofdm = &il->_3945.accum_statistics.rx.ofdm;
- accum_cck = &il->_3945.accum_statistics.rx.cck;
- accum_general = &il->_3945.accum_statistics.rx.general;
- delta_ofdm = &il->_3945.delta_statistics.rx.ofdm;
- delta_cck = &il->_3945.delta_statistics.rx.cck;
- delta_general = &il->_3945.delta_statistics.rx.general;
+ ofdm = &il->_3945.stats.rx.ofdm;
+ cck = &il->_3945.stats.rx.cck;
+ general = &il->_3945.stats.rx.general;
+ accum_ofdm = &il->_3945.accum_stats.rx.ofdm;
+ accum_cck = &il->_3945.accum_stats.rx.cck;
+ accum_general = &il->_3945.accum_stats.rx.general;
+ delta_ofdm = &il->_3945.delta_stats.rx.ofdm;
+ delta_cck = &il->_3945.delta_stats.rx.cck;
+ delta_general = &il->_3945.delta_stats.rx.general;
max_ofdm = &il->_3945.max_delta.rx.ofdm;
max_cck = &il->_3945.max_delta.rx.cck;
max_general = &il->_3945.max_delta.rx.general;
- pos += il3945_statistics_flag(il, buf, bufsz);
+ pos += il3945_stats_flag(il, buf, bufsz);
pos += scnprintf(buf + pos, bufsz - pos, "%-32s current"
"acumulative delta max\n",
"Statistics_Rx - OFDM:");
@@ -332,9 +332,9 @@ ssize_t il3945_ucode_tx_stats_read(struct file *file,
struct il_priv *il = file->private_data;
int pos = 0;
char *buf;
- int bufsz = (sizeof(struct iwl39_statistics_tx) * 48) + 250;
+ int bufsz = (sizeof(struct iwl39_stats_tx) * 48) + 250;
ssize_t ret;
- struct iwl39_statistics_tx *tx, *accum_tx, *delta_tx, *max_tx;
+ struct iwl39_stats_tx *tx, *accum_tx, *delta_tx, *max_tx;
if (!il_is_alive(il))
return -EAGAIN;
@@ -347,14 +347,14 @@ ssize_t il3945_ucode_tx_stats_read(struct file *file,
/*
* The statistic information display here is based on
* the last statistics notification from uCode
* might not reflect the current uCode activity
*/
- tx = &il->_3945.statistics.tx;
- accum_tx = &il->_3945.accum_statistics.tx;
- delta_tx = &il->_3945.delta_statistics.tx;
+ tx = &il->_3945.stats.tx;
+ accum_tx = &il->_3945.accum_stats.tx;
+ delta_tx = &il->_3945.delta_stats.tx;
max_tx = &il->_3945.max_delta.tx;
- pos += il3945_statistics_flag(il, buf, bufsz);
+ pos += il3945_stats_flag(il, buf, bufsz);
pos += scnprintf(buf + pos, bufsz - pos, "%-32s current"
"acumulative delta max\n",
"Statistics_Tx:");
@@ -428,12 +428,12 @@ ssize_t il3945_ucode_general_stats_read(struct file *file,
struct il_priv *il = file->private_data;
int pos = 0;
char *buf;
- int bufsz = sizeof(struct iwl39_statistics_general) * 10 + 300;
+ int bufsz = sizeof(struct iwl39_stats_general) * 10 + 300;
ssize_t ret;
- struct iwl39_statistics_general *general, *accum_general;
- struct iwl39_statistics_general *delta_general, *max_general;
- struct statistics_dbg *dbg, *accum_dbg, *delta_dbg, *max_dbg;
- struct iwl39_statistics_div *div, *accum_div, *delta_div, *max_div;
+ struct iwl39_stats_general *general, *accum_general;
+ struct iwl39_stats_general *delta_general, *max_general;
+ struct stats_dbg *dbg, *accum_dbg, *delta_dbg, *max_dbg;
+ struct iwl39_stats_div *div, *accum_div, *delta_div, *max_div;
if (!il_is_alive(il))
return -EAGAIN;
@@ -446,22 +446,22 @@ ssize_t il3945_ucode_general_stats_read(struct file *file,
/*
* The statistic information display here is based on
* the last statistics notification from uCode
* might not reflect the current uCode activity
*/
- general = &il->_3945.statistics.general;
- dbg = &il->_3945.statistics.general.dbg;
- div = &il->_3945.statistics.general.div;
- accum_general = &il->_3945.accum_statistics.general;
- delta_general = &il->_3945.delta_statistics.general;
+ general = &il->_3945.stats.general;
+ dbg = &il->_3945.stats.general.dbg;
+ div = &il->_3945.stats.general.div;
+ accum_general = &il->_3945.accum_stats.general;
+ delta_general = &il->_3945.delta_stats.general;
max_general = &il->_3945.max_delta.general;
- accum_dbg = &il->_3945.accum_statistics.general.dbg;
- delta_dbg = &il->_3945.delta_statistics.general.dbg;
+ accum_dbg = &il->_3945.accum_stats.general.dbg;
+ delta_dbg = &il->_3945.delta_stats.general.dbg;
max_dbg = &il->_3945.max_delta.general.dbg;
- accum_div = &il->_3945.accum_statistics.general.div;
- delta_div = &il->_3945.delta_statistics.general.div;
+ accum_div = &il->_3945.accum_stats.general.div;
+ delta_div = &il->_3945.delta_stats.general.div;
max_div = &il->_3945.max_delta.general.div;
- pos += il3945_statistics_flag(il, buf, bufsz);
+ pos += il3945_stats_flag(il, buf, bufsz);
pos += scnprintf(buf + pos, bufsz - pos, "%-32s current"
"acumulative delta max\n",
"Statistics_General:");
@@ -77,23 +77,23 @@ ssize_t il3945_ucode_rx_stats_read(struct file *file,
/*
* The statistic information display here is based on
- * the last statistics notification from uCode
+ * the last stats notification from uCode
* might not reflect the current uCode activity
*/
@@ -347,14 +347,14 @@ ssize_t il3945_ucode_tx_stats_read(struct file *file,
/*
* The statistic information display here is based on
- * the last statistics notification from uCode
+ * the last stats notification from uCode
* might not reflect the current uCode activity
*/
@@ -446,22 +446,22 @@ ssize_t il3945_ucode_general_stats_read(struct file *file,
/*
* The statistic information display here is based on
- * the last statistics notification from uCode
+ * the last stats notification from uCode
* might not reflect the current uCode activity
*/